/**
// Simple example of MCDB API usage.
// Retrieving any data from HepML document - article.
//
// Sergey Belov <Sergey.Belov@cern.ch>, Oct 2007
// 
**/

#include <cstdlib>
#include <iostream>

#include "mcdb.hpp"

using namespace mcdb;
using namespace std;

int
main ()
{
  cout << "* MCDB API usage example *" << endl << endl;
  MCDB mcdb;

  cout << "Trying to get an sample article with id 100" << endl << endl;
  
  // Get article with id=100 directly from MCDB server.
  // It's also possible to parse document 
  // by specifying URI (remote http, local file)
#if 1
   cout << "Downloading article with id=100 "
        << "from server and parsing it" << endl << endl;
   Article a = mcdb.getArticle(100);

#else
  
  // or via URI (including local)
  cout << "Parsing local file 'mcdb-example.xml'" << endl << endl;
  Article a = mcdb.getArticle("mcdb-example.xml");
#endif
  
  // last operation was successful if errorCode() is 0
  if ( mcdb.errorCode() ) { 
      cerr << "Error occured while processing the document" << endl;
      return 1;
  }

  cout << "Title: " << a.title() << endl;
  cout << "First author: " << a.authors()[0].firstName() << " "
       << a.authors()[0].lastName () << endl;
  cout << "Number of authors: " << a.authors().size () << endl;
  cout << "Abstract: " << a.abstract() << endl;
  cout << "Generator: " << a.generator().name () << ", " << a.generator ().
    version () << endl;
  cout << "Number of files: " << a.files().size () << endl;
  cout << "Files (all possible URLs for all files):" << endl;



  // printing all paths for each file
  
  cout << "(at once checking if there's a file with name Mixed.PEV)" << endl << endl;
  
  for (vector <File>::iterator f = a.files().begin(); f != a.files().end(); f++) {
      if ( f->hasName("Mixed.PEV") ) {
        cout << endl << "Found file Mixed.PEV, " << "file id: " << f->id() << endl;
      }

      for (vector < string >::iterator s = f->paths().begin (); s != f->paths().end (); s++) {
        cout << "   " << *s << endl;
      }
  }

  cout << endl << "Document was successfully processed" << endl;


  cout << "Start testing file search" << endl
       << "file name in question: events7.txt" << endl;

    vector<File> files  = a.findFilesByName("events_7.txt");
    for (vector <File>::iterator f = files.begin(); f != files.end(); f++) {
      cout << endl << "File id: " << f->id() << endl;

      for (vector < string >::iterator s = f->paths().begin (); s != f->paths().end (); s++) {
        cout << "   " << *s << endl;
      }
  }
    

  return 0;
}
