// MCDB API: file.cpp
// LCG MCDB project, Monte Carlo Data Base
// http://mcdb.cern.ch
// 
// Sergey Belov <Sergey.Belov@cern.ch>, 2007
//

#include "mcdb.hpp"
#include "macro.hpp"

namespace mcdb {

using std::string;
using std::vector;

File::File(): eventsNumber_(0), crossSectionPb_(0),
              csErrorPlusPb_(0), csErrorMinusPb_(0),
	      size_(0), type_(any), id_(0) { }

File::~File() { }

FUNC_SETGET(FileType&, File, type)
FUNC_SETGET(int&, File, id)
FUNC_SETGET(int&, File, eventsNumber)
FUNC_SETGET(unsigned long&, File, size)
FUNC_SETGET(string&, File, checksum)
FUNC_SETGET(float&, File, crossSectionPb)
FUNC_SETGET(float&, File, csErrorPlusPb)
FUNC_SETGET(float&, File, csErrorMinusPb)
FUNC_SETGET(string&, File, comments)
FUNC_SETGET(vector<string>&, File, paths)

// Search 
vector<string> File::findPaths(const string& substr)
{
    using namespace std;

    vector<string>::iterator p = paths_.begin();
    vector<string>::iterator e = paths_.end();
    vector<string> result;
    string to_find = substr;

//    if ( to_find.find("/") != string::npos)
//	to_find.insert( to_find.begin(), '/' );

    for (; p!=e; ++p) {
        if ( p->substr( p->size() - to_find.size(), to_find.size() ) == to_find ) {
	    result.push_back( *p );
	}
    }

    return result;
}


bool File::findSubstrInName(const string& substr)
{
    using namespace std;
    vector<string>::iterator p = paths_.begin();
    vector<string>::iterator e = paths_.end();

    for (; p != e; ++p) {
        string name = "/" + getNameFromPath(*p);
        
        if ( name.find(substr) != string::npos ) {
            return true;
        }
    } // for
    
    return false;
}


bool File::findSubstrInPath(const string& substr)
{
    using namespace std;
    vector<string>::iterator p = paths_.begin();
    vector<string>::iterator e = paths_.end();

    for (; p != e; ++p) {
        if ( p->find(substr) != string::npos ) {
            return true;
        }
    } // for
    
    return false;
}


bool File::hasName(const string& name)
{
    vector<string>::iterator p = paths_.begin();
    vector<string>::iterator e = paths_.end();

    for (; p != e; ++p) {
        if ( name == getNameFromPath(*p) ) {
            return true;
        }
    } // for
    
    return false;
}

string File::getCastorPath()
{
    
    vector<string>::iterator p = paths_.begin();
    vector<string>::iterator e = paths_.end();
	
    for(; p !=e; ++p) {
	if ( p->find("rfio://") == 0 ) {
	    return *p;
	}
    }

    return "";
}


string File::getNameFromPath(const string& path)
{
    using namespace std;
    
    size_t namePos = path.rfind("/");
    
    if ( namePos == string::npos ) {
    	return path;
    }

    namePos++; // position of next symbol after slash
    if ( namePos >= path.size() ) { // end of path?
       	return "";
    }

    return string( path, namePos );
}


bool File::isPlainName(const string& uri)
{
    return ( uri.find("/") == string::npos );
}

} //namespace mcdb

